
#ifndef _C145_li7218_
#define _C145_li7218_

#ifdef __cplusplus
extern "C" {
#endif

extern void F1713_24143(EIF_REFERENCE, EIF_REFERENCE);
extern void F1713_24144(EIF_REFERENCE);
extern void EIF_Minit7218(void);

#ifdef __cplusplus
}
#endif

#endif
